==> foundation-2.6.1.tgz: package/PricetagMultiple/PricetagMultiple.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const PricetagMultiple = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M88.286 67.965c-.022-.038-.052-.069-.076-.105l.002-.001L61.307 21.26l-.015.008a2.08 2.08 0 00-.929-.801l.038-.022-7.986-4.612 8.871 15.365 20.178 34.949-.002.001c.024.036.054.067.076.105a2.091 2.091 0 01-.765 2.855l.014.025-29.861 17.24 1.293 2.239c.026.055.044.112.075.166a2.085 2.085 0 002.772.801l.005.008 32.465-18.743-.014-.025a2.09 2.09 0 00.764-2.854z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M73.88 67.143a2.091 2.091 0 00.765-2.855c-.022-.038-.052-.069-.076-.105l.002-.001-26.905-46.599-.015.008a2.08 2.08 0 00-.929-.801l.038-.022-11.01-6.357v.044a2.082 2.082 0 00-1.846-.107l-.012-.021-.206.119c-.004.003-.009.003-.013.006s-.007.006-.012.008L12.478 22.69a2.078 2.078 0 00-1.037 1.764l-.007-.004v12.714l.021-.012c-.047.427.03.872.261 1.273.014.024.032.042.047.065l26.815 46.446c.026.055.044.112.075.166a2.085 2.085 0 002.772.801l.005.008 32.465-18.743-.015-.025zM29.545 27.522a3.865 3.865 0 111.415-5.279 3.862 3.862 0 01-1.415 5.279z"
  }));
});
PricetagMultiple.displayName = 'PricetagMultiple';
export const PricetagMultipleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/PricetagMultiple/PricetagMultiple.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PricetagMultiple = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M88.286 67.965c-.022-.038-.052-.069-.076-.105l.002-.001L61.307 21.26l-.015.008a2.08 2.08 0 00-.929-.801l.038-.022-7.986-4.612 8.871 15.365 20.178 34.949-.002.001c.024.036.054.067.076.105a2.091 2.091 0 01-.765 2.855l.014.025-29.861 17.24 1.293 2.239c.026.055.044.112.075.166a2.085 2.085 0 002.772.801l.005.008 32.465-18.743-.014-.025a2.09 2.09 0 00.764-2.854z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M73.88 67.143a2.091 2.091 0 00.765-2.855c-.022-.038-.052-.069-.076-.105l.002-.001-26.905-46.599-.015.008a2.08 2.08 0 00-.929-.801l.038-.022-11.01-6.357v.044a2.082 2.082 0 00-1.846-.107l-.012-.021-.206.119c-.004.003-.009.003-.013.006s-.007.006-.012.008L12.478 22.69a2.078 2.078 0 00-1.037 1.764l-.007-.004v12.714l.021-.012c-.047.427.03.872.261 1.273.014.024.032.042.047.065l26.815 46.446c.026.055.044.112.075.166a2.085 2.085 0 002.772.801l.005.008 32.465-18.743-.015-.025zM29.545 27.522a3.865 3.865 0 111.415-5.279 3.862 3.862 0 01-1.415 5.279z"
  }));
});
PricetagMultiple.displayName = 'PricetagMultiple';
export var PricetagMultipleDimensions = {
  height: 100,
  width: 100
};
